@@ -8,6 +8,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #pragma once
 
 #include "mtproto/sender.h"
+#include "spellcheck/spellcheck_types.h"
 
 class ApiWrap;
 
@@ -17,6 +18,16 @@ class Session;
 
 namespace Api {
 
+struct SummaryEntry {
+	Fn<void()> onPremiumRequired = nullptr;
+	TextWithEntities result;
+	LanguageId languageId;
+	bool shown = false;
+	bool loading = false;
+	bool premiumRequired = false;
+	mtpRequestId requestId = 0;
+};
+
 class Transcribes final {
 public:
 	explicit Transcribes(not_null<ApiWrap*> api);
@@ -34,6 +45,13 @@ public:
 	void toggle(not_null<HistoryItem*> item);
 	[[nodiscard]] const Entry &entry(not_null<HistoryItem*> item) const;
 
+	void toggleSummary(
+		not_null<HistoryItem*> item,
+		Fn<void()> onPremiumRequired);
+	[[nodiscard]] const SummaryEntry &summary(
+		not_null<const HistoryItem*> item) const;
+	void checkSummaryToTranslate(FullMsgId id);
+
 	void apply(const MTPDupdateTranscribedAudio &update);
 
 	[[nodiscard]] bool freeFor(not_null<HistoryItem*> item) const;
@@ -47,6 +65,7 @@ public:
 
 private:
 	void load(not_null<HistoryItem*> item);
+	void summarize(not_null<HistoryItem*> item);
 
 	const not_null<Main::Session*> _session;
 	MTP::Sender _api;
@@ -58,6 +77,8 @@ private:
 	base::flat_map<FullMsgId, Entry> _map;
 	base::flat_map<uint64, FullMsgId> _ids;
 
+	base::flat_map<FullMsgId, SummaryEntry> _summaries;
+
 };
 
 } // namespace Api
