@@ -440,13 +440,12 @@ QSize Document::countOptimalSize() {
 			const auto &entry = transcribes->entry(_realParent);
 			const auto update = [=] { repaint(); };
 			voice->transcribe->setLoading(
-				entry.shown && (entry.requestId || entry.pending),
-				update);
+				entry.shown && (entry.requestId || entry.pending));
 			const auto pending = entry.pending;
 			auto descriptor = pending
 				? Lottie::IconDescriptor{
 					.name = u"transcribe_loading"_q,
-					.color = &st::historyTextInFg,
+					.color = &st::attentionButtonFg, // Any contrast.
 					.sizeOverride = Size(st::historyTranscribeLoadingSize),
 					.colorizeUsingAlpha = true,
 				}
