@@ -621,15 +621,26 @@ void TopBar::updateCollectibleStatus() {
 		_animatedPoints.clear();
 		_pinnedToTopGifts.clear();
 	}
-	if (colorProfile && !colorProfile->palette.empty()) {
+	const auto verifiedFg = [&]() -> std::optional<QColor> {
+		if (collectible) {
+			return Ui::BlendColors(
+				collectible->edgeColor,
+				collectible->centerColor,
+				0.2);
+		}
+		if (colorProfile && !colorProfile->palette.empty()) {
+			return Ui::BlendColors(
+				colorProfile->palette.back(),
+				colorProfile->palette.size() == 1 ? Qt::white : Qt::black,
+				0.2);
+		}
+		return std::nullopt;
+	}();
+	if (verifiedFg) {
 		const auto copyStVerified = [&](const style::InfoPeerBadge &st) {
 			auto result = std::make_unique<style::InfoPeerBadge>(
 				base::duplicate(st));
-			auto fg = std::make_shared<style::owned_color>(
-				Ui::BlendColors(
-					colorProfile->palette.back(),
-					colorProfile->palette.size() == 1 ? Qt::white : Qt::black,
-					0.2));
+			auto fg = std::make_shared<style::owned_color>(*verifiedFg);
 			result->premiumFg = fg->color();
 			return std::shared_ptr<style::InfoPeerBadge>(
 				result.release(),
@@ -931,8 +942,10 @@ void TopBar::setupActions(not_null<Window::SessionController*> controller) {
 		return;
 	}
 	if (!topic
-		&& ((chat && !chat->amCreator())
-			|| (channel && !channel->amCreator()))) {
+		&& ((chat && !chat->amCreator() && !chat->hasAdminRights())
+			|| (channel
+				&& !channel->amCreator()
+				&& !channel->hasAdminRights()))) {
 		const auto show = controller->uiShow();
 		const auto reportButton = Ui::CreateChild<TopBarActionButton>(
 			this,
