@@ -382,7 +382,7 @@ void Dropdown::paintEvent(QPaintEvent *e) {
 	// draw shadow
 	auto shadowedRect = rect().marginsRemoved(getMargin());
 	auto shadowedSides = RectPart::Left | RectPart::Right | RectPart::Bottom;
-	Ui::Shadow::paint(p, shadowedRect, width(), st::defaultRoundShadow, shadowedSides);
+	Ui::Shadow::paint(p, shadowedRect, width(), st::roundShadowRadius8px, shadowedSides);
 	const auto &corners = Ui::CachedCornerPixmaps(Ui::MenuCorners);
 	const auto fill = Ui::CornersPixmaps{
 		.p = { QPixmap(), QPixmap(), corners.p[2], corners.p[3] },
