@@ -597,6 +597,8 @@ void SetupPasskeys(
 	) | rpl::map([=](const QString &loading, int count) {
 		return !session->passkeys().listKnown()
 			? loading
+			: count == 1
+			? session->passkeys().list().front().name
 			: count
 			? QString::number(count)
 			: tr::lng_settings_cloud_password_off(tr::now);
@@ -658,6 +660,9 @@ void SetupLoginEmail(
 	) | rpl::map([](const State &state) { return state.loginEmailPattern; });
 	auto text = tr::lng_settings_cloud_login_email_section_title();
 	auto label = rpl::duplicate(email) | rpl::map([](QString email) {
+		if (email.contains(' ')) {
+			return tr::lng_settings_cloud_password_off(tr::now, tr::rich);
+		}
 		return Ui::Text::WrapEmailPattern(
 			email.replace(QRegularExpression("\\*{4,}"), "****"));
 	});
