@@ -76,7 +76,7 @@ void CreateMaskCorners() {
 }
 
 void CreatePaletteCorners() {
-	PrepareCorners(MenuCorners, st::roundRadiusSmall, st::menuBg);
+	PrepareCorners(MenuCorners, st::innerDropdownRadius, st::menuBg);
 	PrepareCorners(BoxCorners, st::boxRadius, st::boxBg);
 	PrepareCorners(DateCorners, st::dateRadius, st::msgDateImgBg);
 	PrepareCorners(OverviewVideoCorners, st::overviewVideoStatusRadius, st::msgDateImgBg);
