@@ -71,7 +71,7 @@ using Core::WindowPosition;
 
 base::options::toggle OptionNewWindowsSizeAsFirst({
 	.id = kOptionNewWindowsSizeAsFirst,
-	.name = "Adjust size of new chat windows.",
+	.name = "Adjust size of new chat windows",
 	.description = "Open new windows with a size of the main window.",
 });
 
